# fsociety

[![PyPI](https://img.shields.io/pypi/v/fsociety?color=orange&logo=pypi&logoColor=orange&style=flat-square)](https://pypi.org/project/fsociety/)
[![Python Version](https://img.shields.io/badge/python-3.6%2B-blue?logo=python&style=flat-square)](https://www.python.org/downloads/)
![PyPI - Downloads](https://img.shields.io/pypi/dm/fsociety?style=flat-square)
[![Docker Cloud build](https://img.shields.io/docker/cloud/build/fsocietyteam/fsociety?style=flat-square)](https://hub.docker.com/r/fsocietyteam/fsociety)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-organge.svg?logo=git&logoColor=organge&style=flat-square)](http://makeapullrequest.com)

A Modular Penetration Testing Framework

[![Packages](https://img.shields.io/badge/PACKAGES.md-red?style=flat-square)](https://github.com/fsociety-team/fsociety/blob/main/PACKAGES.md) [![Changelog](https://img.shields.io/badge/CHANGELOG.md-red?style=flat-square)](https://github.com/fsociety-team/fsociety/blob/main/CHANGELOG.md)

[![fsociety](https://raw.githubusercontent.com/fsociety-team/fsociety/main/images/fsociety.png)](https://github.com/fsociety-team/fsociety)

![cli](https://raw.githubusercontent.com/fsociety-team/fsociety/main/images/cli.png)

## Install

```bash
pip install fsociety
```

## Update

```bash
pip install --upgrade fsociety
```

## Usage

```bash
usage: fsociety [-h] [-i] [-s]

A Penetration Testing Framework

optional arguments:
  -h, --help     show this help message and exit
  -i, --info     gets fsociety info
  -s, --suggest  suggest a tool
```

## Develop

```bash
git clone https://github.com/fsociety-team/fsociety.git
pip install -e ".[dev]"
```

## Docker

```bash
docker pull fsocietyteam/fsociety
docker run -it fsocietyteam/fsociety fsociety
```

## License

This software is licensed under the [MIT](https://github.com/fsociety-team/fsociety/blob/main/LICENSE) License.

[![Twitter Follow](https://img.shields.io/badge/fuck%20it-ship%20it-blue?style=flat-square)](https://twitter.com/fsociety_team) [![Twitter Follow](https://img.shields.io/twitter/follow/fsociety_team?color=blue&style=flat-square)](https://twitter.com/fsociety_team)
